<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Moral
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function emerge_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}
	
	// When  hero content is enabled or disabled.
	$hero_content = get_theme_mod( 'emerge_hero_content', 'custom' );
	$hero_content_enable_entire = get_theme_mod( 'emerge_hero_content_enable_on_entire', false );
	
	if ( 'disable' === $hero_content ) {
		$classes[] =  'relative-header';
	} else {
		if ( ! emerge_is_frontpage() && $hero_content_enable_entire ) {
			$classes[] =  'absolute-header';
		} elseif( emerge_is_frontpage() ) {
			$classes[] =  'absolute-header';
		} else {
			$classes[] =  'relative-header';
		}
	}

	// When menu type is classic or modern.
	$menu_type = get_theme_mod( 'emerge_menu_type', 'classic' );
	$classes[] = $menu_type . '-menu';

	// When menu is sticky.
	$menu_sticky = get_theme_mod( 'emerge_make_menu_sticky', false );
	if ( $menu_sticky ) {
		$classes[] = 'menu-sticky';
	}

	// When  color scheme is light or dark.
	$color_scheme = get_theme_mod( 'emerge_color_scheme', 'lite' );
	$classes[] = $color_scheme . '-version';
	
	// When global archive layout is checked.
	if ( is_archive() || emerge_is_latest_posts() || is_404() || is_search() ) {
		$archive_sidebar = get_theme_mod( 'emerge_archive_sidebar', 'right' ); 
		$classes[] = $archive_sidebar . '-sidebar';
	} else if ( is_single() ) { // When global post sidebar is checked.
    	$emerge_post_sidebar_meta = get_post_meta( get_the_ID(), 'emerge-select-sidebar', true );
    	if ( ! empty( $emerge_post_sidebar_meta ) ) {
			$classes[] = $emerge_post_sidebar_meta . '-sidebar';
    	} else {
			$global_post_sidebar = get_theme_mod( 'emerge_global_post_layout', 'right' ); 
			$classes[] = $global_post_sidebar . '-sidebar';
    	}
	} elseif ( emerge_is_frontpage_blog() || is_page() ) {
		if ( emerge_is_frontpage_blog() ) {
			$page_id = get_option( 'page_for_posts' );
		} else {
			$page_id = get_the_ID();
		}

    	$emerge_page_sidebar_meta = get_post_meta( $page_id, 'emerge-select-sidebar', true );
		if ( ! empty( $emerge_page_sidebar_meta ) ) {
			$classes[] = $emerge_page_sidebar_meta . '-sidebar';
		} else {
			$global_page_sidebar = get_theme_mod( 'emerge_global_page_layout', 'right' ); 
			$classes[] = $global_page_sidebar . '-sidebar';
		}
	}

	// Site layout classes
	$site_layout = get_theme_mod( 'emerge_site_layout', 'wide' );
	if ( 'box' === $site_layout ) {
		$classes[] = 'boxed';
	}

	return $classes;
}
add_filter( 'body_class', 'emerge_body_classes' );

function emerge_post_classes( $classes ) {
	if ( emerge_is_page_displays_posts() ) {
		// Search 'has-post-thumbnail' returned by default and remove it.
		$key = array_search( 'has-post-thumbnail', $classes );
		unset( $classes[ $key ] );
		
		$archive_img_enable = get_theme_mod( 'emerge_enable_archive_featured_img', true );

		if( has_post_thumbnail() && $archive_img_enable ) {
			$classes[] = 'has-post-thumbnail';
		} else {
			$classes[] = 'no-post-thumbnail';
		}
	}

	return $classes;
}
add_filter( 'post_class', 'emerge_post_classes' );

/**
 * Excerpt length
 * 
 * @since Moral 1.0.0
 * @return Excerpt length
 */
function emerge_excerpt_length( $length ){
	if ( is_admin() ) {
		return $length;
	}

	$length = get_theme_mod( 'emerge_archive_excerpt_length', 60 );
	return $length;
}
add_filter( 'excerpt_length', 'emerge_excerpt_length', 999 );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function emerge_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'emerge_pingback_header' );

/**
 * Get an array of post id and title.
 * 
 */
function emerge_get_post_choices() {
	$choices = array();
	$args = array( 'numberposts' => -1, );
	$posts = get_posts( $args );

	foreach ( $posts as $post ) {
		$id = $post->ID;
		$title = $post->post_title;
		$choices[ $id ] = $title;
	}

	return $choices;
}

/**
 * Get an array of cat id and title.
 * 
 */
function emerge_get_post_cat_choices() {
	$choices = array( '' => esc_html__( '--Select--', 'blogbok-pro' ) );
	$cats = get_categories();

	foreach ( $cats as $cat ) {
		$id = $cat->term_id;
		$title = $cat->name;
		$choices[ $id ] = $title;
	}

	return $choices;
}

/**
 * Checks to see if we're on the homepage or not.
 */
function emerge_is_frontpage() {
	return ( is_front_page() && ! is_home() );
}

/**
 * Checks to see if Static Front Page is set to "Your latest posts".
 */
function emerge_is_latest_posts() {
	return ( is_front_page() && is_home() );
}

/**
 * Checks to see if Static Front Page is set to "Posts page".
 */
function emerge_is_frontpage_blog() {
	return ( is_home() && ! is_front_page() );
}

/**
 * Checks to see if the current page displays any kind of post listing.
 */
function emerge_is_page_displays_posts() {
	return ( emerge_is_frontpage_blog() || is_search() || is_archive() || emerge_is_latest_posts() );
}

/**
 * Shows a breadcrumb for all types of pages.  This is a wrapper function for the Breadcrumb_Trail class,
 * which should be used in theme templates.
 *
 * @since  1.0.0
 * @access public
 * @param  array $args Arguments to pass to Breadcrumb_Trail.
 * @return void
 */
function emerge_breadcrumb( $args = array() ) {
	$breadcrumb = apply_filters( 'breadcrumb_trail_object', null, $args );

	if ( ! is_object( $breadcrumb ) )
		$breadcrumb = new Breadcrumb_Trail( $args );

	return $breadcrumb->trail();
}

/**
 * Pagination in archive/blog/search pages.
 */
function emerge_posts_pagination() { 
	$archive_pagination = get_theme_mod( 'emerge_archive_pagination_type', 'numeric' );
	if ( 'disable' === $archive_pagination ) {
		return;
	}
	if ( 'numeric' === $archive_pagination ) {
		the_posts_pagination();
	} elseif ( 'older_newer' === $archive_pagination ) {
		the_posts_navigation();
	}
}

function emerge_get_svg_by_url( $url = false ) {
	if ( ! $url ) {
		return false;
	}

	$social_icons = emerge_social_links_icons();

	foreach ( $social_icons as $attr => $value ) {
		if ( false !== strpos( $url, $attr ) ) {
			return emerge_get_svg( array( 'icon' => esc_attr( $value ) ) );
		}
	}
}

/**
 * Count number of widgets in a sidebar
 * Used to add classes to widget areas so widgets can be displayed one, two, three or four per row
 */
/**
 * Count number of widgets in a sidebar
 * Used to add classes to widget areas so widgets can be displayed one, two, three or four per row
 * @param  string $sidebar_id Sidebar widget area id.
 * @return int             Number of widgets in the sidebar
 */
function emerge_count_widgets( $sidebar_id = '' ) {
	if ( empty( $sidebar_id ) ) {
		return false;
	}
	// If loading from front page, consult $_wp_sidebars_widgets rather than options
	// to see if wp_convert_widget_settings() has made manipulations in memory.
	global $_wp_sidebars_widgets;
	if ( empty( $_wp_sidebars_widgets ) ) :
		$_wp_sidebars_widgets = get_option( 'sidebars_widgets', array() );
	endif;
	
	$sidebars_widgets_count = $_wp_sidebars_widgets;
	
	if ( isset( $sidebars_widgets_count[ $sidebar_id ] ) ) :
		$widget_count = count( $sidebars_widgets_count[ $sidebar_id ] );
		return $widget_count;
	else:
		return false;
	endif;
}